@@ -28,7 +28,6 @@ except ImportError:
     anyconfig = None
 
 import immp
-from immp.hook.command import CommandRole, CommandScope, command
 
 
 log = logging.getLogger(__name__)
@@ -58,8 +57,9 @@ class _Schema:
 
 def _load_file(path):
     if anyconfig:
-        # anyconfig incorrectly parses ac_template=False as positive (`ac_template is not None`).
-        return anyconfig.load(path, ac_template=None)
+        # Note: anyconfig v0.11.0 parses ac_template=False as positive (fixed in v0.11.1).
+        # https://github.com/ssato/python-anyconfig/pull/126
+        return anyconfig.load(path, ac_template=False)
     else:
         with open(path, "r") as reader:
             return json.load(reader)
@@ -115,8 +115,8 @@ def main(path, write=False):
         logging.config.dictConfig(config["logging"])
     else:
         logging.basicConfig(level=logging.INFO)
-        for handler in logging.root.handlers:
-            handler.addFilter(immp.LocalFilter())
+        logging.getLogger().setLevel(logging.WARNING)
+        logging.getLogger(immp.__name__).setLevel(logging.INFO)
     log.info("Creating plugs and hooks")
     host = config_to_host(config, path, write)
     loop = get_event_loop()
@@ -165,17 +165,6 @@ class RunnerHook(immp.ResourceHook):
         self._path = path
         self.writeable = writeable
 
-    def _test(self, channel, user):
-        return self.writeable
-
-    @command("run-write", scope=CommandScope.private, role=CommandRole.admin, test=_test)
-    async def write(self, msg):
-        """
-        Force a write of the live config out to the configured file.
-        """
-        self.write_config()
-        await msg.channel.send(immp.Message(text="\N{WHITE HEAVY CHECK MARK} Written"))
-
     @staticmethod
     def _config_feature(section, name, obj, priority=None):
         if obj.virtual:
