@@ -1,5 +1,5 @@
 """
-Connect to `Discord <https://discordapp.com>`_ as a bot.
+Connect to `Discord <https://discord.com>`_ as a bot.
 
 Requirements:
     Extra name: ``discord``
@@ -26,16 +26,16 @@ Config:
 
 Note that the token is neither a client ID nor client secret -- you need to enable bot features for
 your app, and collect the token from there.  New apps can be created from the `My Apps
-<https://discordapp.com/developers/applications/me>`_ page in the developer docs.
+<https://discord.com/developers/applications/me>`_ page in the developer docs.
 
 Channel sources should be Discord's numerical IDs but quoted as strings, e.g. ``"123456789012"``.
 You can enable Advanced > Developer Mode in your Discord app settings in order to enable Copy ID
 menu options in various places across the UI.
 
 Because gateway connections can't customise the sender when pushing new messages, you may also want
-an `incoming webhook <https://discordapp.com/developers/docs/resources/webhook>`_  configured for
-each channel you intend to send messages to.  A new webhook can be created over the API, or in the
-UI via Edit Channel > Webhooks.  A fallback style incorporating the user's name in the message text
+an `incoming webhook <https://discord.com/developers/docs/resources/webhook>`_  configured for each
+channel you intend to send messages to.  A new webhook can be created over the API, or in the UI
+via Edit Channel > Webhooks.  A fallback style incorporating the user's name in the message text
 will be used in lieu of a webhook, e.g. with direct messages.
 """
 
@@ -267,54 +267,31 @@ class DiscordRichText(immp.RichText):
                         # First line of pre block would set the code language and be hidden.
                         text += "\n"
                     active.append(tag)
-            if segment.mention and isinstance(segment.mention.plug, DiscordPlug):
-                text += "<@{}>".format(segment.mention.id)
-            elif segment.link:
-                if webhook:
-                    text += "[{}]({})".format(segment.text, segment.link)
-                elif segment.text == segment.link:
-                    text += segment.text
+            parsed = segment.text
+            if not segment.code and not segment.pre:
+                link = None
+                if not segment.mention:
+                    link = segment.link
+                elif segment.mention.plug.network_name == discord.network_name:
+                    parsed = "<@{}>".format(segment.mention.id)
                 else:
-                    text += "{} [{}]".format(segment.text, segment.link)
-            else:
-                text += segment.text
+                    link = segment.mention.link
+                if link:
+                    if webhook:
+                        parsed = "[{}]({})".format(segment.text, link)
+                    elif segment.text == segment.link:
+                        pass
+                    elif segment.text_is_link:
+                        # Implicitly add the protocol to gain automatic linking.
+                        parsed = segment.link
+                    else:
+                        parsed = "{} [{}]".format(segment.text, link)
+            text += parsed
         for tag in reversed(active):
             # Close all remaining tags.
             text += tag
         return re.sub(r":([^: ]+):", partial(cls._sub_emoji, discord), text)
 
-    @classmethod
-    def chunk_split(cls, text):
-        """
-        Split long messages into parts of at most 2000 characters.
-
-        Args:
-            text (str):
-                Markdown-formatted message to be sent.
-
-        Returns:
-            str list:
-                Chunked message text.
-        """
-        parts = []
-        current = []
-        for line in text.splitlines():
-            size = sum(len(part) + 1 for part in current)
-            extra = len(line)
-            if size + extra >= 2000:
-                if current:
-                    # The message is full, split here.
-                    parts.append("\n".join(current))
-                    current.clear()
-                if extra >= 2000:
-                    # The line itself is too long, split on whitespace instead.
-                    *lines, line = wrap(line, 2000, expand_tabs=False, replace_whitespace=False)
-                    parts.extend(lines)
-            current.append(line)
-        if current:
-            parts.append("\n".join(current))
-        return parts
-
 
 class DiscordMessage(immp.Message):
     """
@@ -395,7 +372,7 @@ class DiscordMessage(immp.Message):
 
         Returns.
             discord.Embed:
-                Discord API `embed <https://discordapp.com/developers/docs/resources/channel>`_
+                Discord API `embed <https://discord.com/developers/docs/resources/channel>`_
                 object.
         """
         icon = "\N{RIGHTWARDS ARROW WITH HOOK}" if reply else "\N{SPEECH BALLOON}"
@@ -464,7 +441,7 @@ class DiscordClient(discord.Client):
 
 class DiscordPlug(immp.Plug, immp.HTTPOpenable):
     """
-    Plug for a `Discord <https://discordapp.com>`_ server.
+    Plug for a `Discord <https://discord.com>`_ server.
     """
 
     schema = _Schema.config
@@ -544,7 +521,7 @@ class DiscordPlug(immp.Plug, immp.HTTPOpenable):
             guild = "@me"
         else:
             return None
-        return "https://discordapp.com/channels/{}/{}".format(guild, dc_channel.id)
+        return "https://discord.com/channels/{}/{}".format(guild, dc_channel.id)
 
     async def channel_rename(self, channel, title):
         dc_channel = self._get_channel(channel)
@@ -567,6 +544,23 @@ class DiscordPlug(immp.Plug, immp.HTTPOpenable):
         else:
             return []
 
+    async def channel_link_create(self, channel, shared=True):
+        dc_channel = self._get_channel(channel)
+        invite = await dc_channel.create_invite(max_uses=(0 if shared else 1),
+                                                unique=(not shared))
+        log.debug("Created invite link for %r: %r", channel.source, invite.url)
+        return invite.url
+
+    async def channel_link_revoke(self, channel, link=None):
+        if not link:
+            return
+        dc_channel = self._get_channel(channel)
+        for invite in await dc_channel.invites():
+            if invite.url == link:
+                await invite.delete()
+                log.debug("Revoked invite link for %r: %r", channel.source, link)
+                break
+
     async def channel_history(self, channel, before=None):
         dc_channel = self._get_channel(channel)
         dc_before = await dc_channel.fetch_message(before.id) if before else None
@@ -636,7 +630,7 @@ class DiscordPlug(immp.Plug, immp.HTTPOpenable):
         if webhook and msg.user:
             # Sending via webhook: multiple embeds and files supported.
             requests = []
-            text = None
+            rich = None
             if reply_embed:
                 # Webhooks can't reply to other messages, quote the target in an embed instead.
                 # https://github.com/discord/discord-api-docs/issues/2251
@@ -646,15 +640,22 @@ class DiscordPlug(immp.Plug, immp.HTTPOpenable):
                 if msg.action:
                     for segment in rich:
                         segment.italic = True
-                if msg.edited:
-                    rich.append(immp.Segment(" (edited)", italic=True))
-                lines = DiscordRichText.chunk_split(DiscordRichText.to_markdown(self, rich, True))
-                if len(lines) > 1:
-                    # Multiple messages required to accommodate the text.
-                    requests.extend(webhook.send(content=line, wait=True, username=name,
-                                                 avatar_url=image) for line in lines)
+            if msg.edited:
+                if rich:
+                    rich.append(immp.Segment(" "))
                 else:
-                    text = lines[0]
+                    rich = immp.RichText()
+                rich.append(immp.Segment("(edited)", italic=True))
+            text = None
+            if rich:
+                mark = DiscordRichText.to_markdown(self, rich, True)
+                chunks = immp.RichText.chunked_plain(mark, 2000)
+                if len(chunks) > 1:
+                    # Multiple messages required to accommodate the text.
+                    requests.extend(webhook.send(content=chunk, wait=True, username=name,
+                                                 avatar_url=image) for chunk in chunks)
+                else:
+                    text = chunks[0]
             if text or embeds or files:
                 requests.append(webhook.send(content=text, wait=True, username=name,
                                              avatar_url=image, files=files,
@@ -663,22 +664,23 @@ class DiscordPlug(immp.Plug, immp.HTTPOpenable):
         else:
             # Sending via client: only a single embed per message.
             requests = []
-            text = embed = None
-            lines = []
+            text = embed = desc = None
+            chunks = []
             rich = msg.render(link_name=False, edit=msg.edited) or None
             if rich:
-                text, *lines = DiscordRichText.chunk_split(DiscordRichText.to_markdown(self, rich))
+                mark = DiscordRichText.to_markdown(self, rich)
+                text, *chunks = immp.RichText.chunked_plain(mark, 2000)
             if reply_embed and not reply_ref:
                 embeds.append((reply_embed, None))
             if len(embeds) == 1:
                 # Attach the only embed to the message text.
-                embed, _ = embeds.pop()
+                embed, desc = embeds.pop()
             if text or embed or files:
                 # Primary message: set reference for reply-to if applicable.
-                requests.append(dc_channel.send(content=text, embed=embed, files=files,
+                requests.append(dc_channel.send(content=text or desc, embed=embed, files=files,
                                                 reference=reply_ref))
             # Send the remaining text if multiple messages were required to accommodate it.
-            requests.extend(dc_channel.send(content=line) for line in lines)
+            requests.extend(dc_channel.send(content=chunk) for chunk in chunks)
             for embed, desc in embeds:
                 # Send any additional embeds in their own separate messages.
                 content = None
