@@ -86,8 +86,11 @@ class _Schema:
     chat = immp.Schema({"id": int,
                         "type": str,
                         immp.Optional("title"): immp.Nullable(str),
+                        immp.Optional("invite_link"): immp.Nullable(str),
                         immp.Optional("username"): immp.Nullable(str)})
 
+    link = immp.Schema({"invite_link": str})
+
     entity = immp.Schema({"type": str,
                           "offset": int,
                           "length": int,
@@ -391,16 +394,22 @@ class TelegramSegment(immp.Segment):
                 HTML-formatted string.
         """
         text = segment.text.replace("&", "&amp;").replace("<", "&lt;").replace(">", "&gt;")
-        if segment.mention and segment.mention.plug.network_id == telegram.network_id:
-            if segment.mention.username:
-                # Telegram will parse this automatically.
-                text = "@{}".format(segment.mention.username)
+        link = None
+        if segment.mention:
+            if segment.mention.plug.network_name == telegram.network_name:
+                if segment.mention.username:
+                    # Telegram will parse this automatically.
+                    text = "@{}".format(segment.mention.username)
+                else:
+                    # Make a link that looks like a mention.
+                    text = ("<a href=\"tg://user?id={}\">{}</a>"
+                            .format(segment.mention.id, segment.mention.real_name))
             else:
-                # Make a link that looks like a mention.
-                text = ("<a href=\"tg://user?id={}\">{}</a>"
-                        .format(segment.mention.id, segment.mention.real_name))
-        elif segment.link:
-            text = "<a href=\"{}\">{}</a>".format(segment.link, text)
+                link = segment.mention.link
+        else:
+            link = segment.link
+        if link:
+            text = "<a href=\"{}\">{}</a>".format(link, text)
         if segment.code:
             text = "<code>{}</code>".format(text)
         if segment.pre:
@@ -634,8 +643,8 @@ class TelegramMessage(immp.Message):
         if message["from"] and not _HiddenSender.has(message["from"]["id"]):
             user = TelegramUser.from_bot_user(telegram, message["from"])
         elif message["sender_chat"] and not _HiddenSender.has(message["sender_chat"]["id"]):
-            user = TelegramUser.from_bot_chat(telegram, message["sender_chat"],
-                                              message["author_signature"])
+            user = TelegramUser.from_bot_channel(telegram, message["sender_chat"],
+                                                 message["author_signature"])
         if message["reply_to_message"]:
             reply_to = await cls.from_bot_message(telegram, message["reply_to_message"])
         # At most one of these fields will be set.
@@ -1328,6 +1337,33 @@ class TelegramPlug(immp.Plug, immp.HTTPOpenable):
             await self._api("kickChatMember", params={"chat_id": channel.source,
                                                       "user_id": user.id})
 
+    async def channel_link_create(self, channel, shared=True):
+        params = {"chat_id": channel.source}
+        if not shared:
+            # Create a new single-use invite link.
+            params["member_limit"] = 1
+            meta = await self._api("createChatInviteLink", _Schema.link, params=params)
+            link = meta["invite_link"]
+            log.debug("Created invite link for %r: %r", channel.source, link)
+            return link
+        chat = await self._api("getChat", _Schema.chat, params=params)
+        # Reuse a primary invite link if available, otherwise create a new one.
+        if chat["invite_link"]:
+            return chat["invite_link"]
+        link = await self._api("exportChatInviteLink", _Schema.link, params=params)
+        log.debug("Regenerated invite link for %r: %r", channel.source, link)
+        return link
+
+    async def channel_link_revoke(self, channel, link=None):
+        if link:
+            await self._api("revokeChatInviteLink", params={"chat_id": channel.source,
+                                                            "invite_link": link})
+            log.debug("Revoked invite link for %r: %r", channel.source, link)
+        else:
+            # Revoke the primary link by requesting a new one.
+            await self._api("exportChatInviteLink", params={"chat_id": channel.source})
+            log.debug("Regenerated invite link for %r", channel.source)
+
     async def channel_history(self, channel, before=None):
         if not self._client:
             log.debug("Client auth required to retrieve messages")
@@ -1447,6 +1483,7 @@ class TelegramPlug(immp.Plug, immp.HTTPOpenable):
             quote = True
         if msg.text or quote:
             rich = msg.render(edit=msg.edited, quote_reply=quote)
+        fits_caption = rich and len(rich) < 1024
         # If there's exactly one file attachment that we can attach a caption to, use that for the
         # message text, otherwise send the text first in its own message.
         parts = []
@@ -1460,20 +1497,21 @@ class TelegramPlug(immp.Plug, immp.HTTPOpenable):
         requests = []
         # Send the primary attachment, or the leading text-only message, with any reply metadata.
         primary = None
-        if len(captionable) == 1:
+        if len(captionable) == 1 and fits_caption:
             primary = captionable[0]
             requests.append(self._upload_attachment(chat, msg, primary, reply_to, rich))
         elif rich:
-            text = "".join(TelegramSegment.to_html(self, segment) for segment in rich)
-            # Prevent linked user names generating link previews.
-            no_link_preview = "true" if msg.user and msg.user.link else "false"
-            requests.append(self._api("sendMessage", _Schema.message,
-                                      params={"chat_id": chat,
-                                              "text": text,
-                                              "parse_mode": "HTML",
-                                              "disable_web_page_preview": no_link_preview,
-                                              "reply_to_message_id": reply_to,
-                                              "allow_sending_without_reply": "true"}))
+            for chunk in rich.chunked(4096):
+                text = "".join(TelegramSegment.to_html(self, segment) for segment in chunk)
+                # Prevent linked user names generating link previews.
+                no_link_preview = "true" if msg.user and msg.user.link else "false"
+                requests.append(self._api("sendMessage", _Schema.message,
+                                          params={"chat_id": chat,
+                                                  "text": text,
+                                                  "parse_mode": "HTML",
+                                                  "disable_web_page_preview": no_link_preview,
+                                                  "reply_to_message_id": reply_to,
+                                                  "allow_sending_without_reply": "true"}))
         # Send any remaining attachments as auxilary messages.
         for attach in msg.attachments:
             if attach is primary:
